% Construct and manipulate reservoir simulation grid data structure.
%
% Files
%   buildCornerPtNodes     - Construct physical nodal coordinates for CP grid.
%   cart2active            - Compute active cell numbers from linear Cartesian index.
%   cartGrid               - Construct 2d or 3d Cartesian grid in physical space.
%   cellNodes              - Extract local-to-global vertex numbering for grid cells.
%   compareGrids           - Determine if two grid structures are the same.
%   computeGeometry        - Compute geometry of grid.


%   extractSubgrid         - Construct valid grid definition from subset of existing grid cells.
%   grid_structure         - Grid structure used in MATLAB Reservoir Simulation Toolbox.
%   makeInternalBoundary   - Make internal boundary in grid along FACES
%   makeLayeredGrid        - Extrude 2D grid to layered 3D grid with n layers.
%   pebi                   - Compute dual grid of triangular grid G.
%   processGRDECL          - Compute grid topology and geometry from pillar grid description.
%   removeCells            - Remove cells from grid and renumber cells, faces and nodes.
%   removeInternalBoundary - Remove internal boundary in grid by merging faces in face list N

%   sortGrid               - Permute nodes, faces and cells to sorted form

%   tensorGrid             - Construct Cartesian grid with variable physical cell sizes.



%{
Copyright 2009, 2010, 2011, 2012 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}
%   buildCornerPtPillars   - Construct physical nodal coordinates for CP grid.
%   hexahedralGrid         - Construct valid grid definition from points and list of hexahedra
%   processFaults          - Construct fault structure from input specification (keyword 'FAULTS')
%   refineDeck             - grdecl=refineGrdecl(grdecl,dim)
%   refineGrdecl           - grdecl=refineGrdecl(grdecl,dim)
%   removeFaultBdryFaces   - Remove fault faces on boundary
%   removePinch            - Uniquify nodes, remove pinched faces and cells.
%   tetrahedralGrid        - Construct valid grid definition from points and tetrahedron list
%   triangleGrid           - Construct valid grid definition from points and triangle list
%   triangulateFaces       - Split face f in grid G into subfaces.
