function h = plotFaceNumbers(g, varargin)
   if mod(nargin, 2),
      f = 1:g.faces.num;
   else
      f = varargin{1};
      varargin = varargin(2:end);
   end
   if isfield(g, 'parent'),
      if ~isfield(g.faces, 'centroids'),
         dispif(mrstVerbose, 'Adding (some) geometry to coarse grid.');
         g = computeCoarseGeometry(g);
      end
   elseif ~isfield(g.faces, 'centroids'),
      dispif(mrstVerbose, 'Adding geometry to grid.');
      g = computeGeometry(g);
   else
      error('');
   end
   v = ishold;hold on;
   coord = num2cell(g.faces.centroids(f,:), 1);
   h=text(coord{:}, num2str(f(:)), varargin{:});
   if ~v, hold off; end      
end


function cg = computeCoarseGeometry(cg)
   if ~isfield(cg.parent.faces, 'centroids'),
      dispif(mrstVerbose, 'Adding geometry to fine grid.');
      cg.parent = computeGeometry(cg.parent);
   end
   
   cg.faces.centroids = zeros(cg.faces.num, cg.griddim);
   faceno = rldecode(1:cg.faces.num, diff(cg.faces.connPos), 2)';
   for i=1:cg.griddim,
      cg.faces.centroids(:,i) = accumarray(faceno, cg.parent.faces.centroids(cg.faces.fconn, i));
   end
   cg.faces.centroids = bsxfun(@rdivide, cg.faces.centroids, accumarray(faceno, cg.parent.faces.areas(cg.faces.fconn)));   
end
