function V = volumeByGaussGreens(G)  
   
   cellNo = rldecode(1:G.cells.num, diff(G.cells.facePos), 2) .';
   
   sgn = 1-2*(G.faces.neighbors(G.cells.faces(:,1),2)==cellNo);
   R   = G.faces.centroids(G.cells.faces(:,1),:);% - G.cells.centroids(cellNo,:);
   N   = bsxfun(@times, G.faces.normals(G.cells.faces(:,1),:), sgn);
   
   %% Reshape N and R to a block-diagonal matrices.
   d   = G.griddim;
   [i,j] = blockDiagIndex(repmat(d, [G.cells.num, 1]), diff(G.cells.facePos));
   
   % reshape
   R  = sparse(i,j,R')';
   N  = sparse(i,j,N')';
   
   %% Gauss-Greens formula
   % Apply Gauss-Greens formula to vector field [x,0,0], 
   %
   %     v = \int_C1 div([x,0,0]) dv = \int_{dC1} x·n ds.
   % 
   % For polygons and polyhedra we have:
   % 
   %     \int_{dC1} x·n ds = R(:,1)'*N(:,1).
   %
   % The same holds for [0,y,0] and [0,0,z].
   
   V = reshape(spdiags(R'*N, 0), d, [])';
end
